@@ -110,12 +110,14 @@ write_rtf_output <- function(rs, ls, rtf_path, orig_path, tmp_dir) {
                                 "\\margt", round(rs$margin_top * conv),
                                 "\\margb", round(rs$margin_bottom  * conv))
 
+  # Line spacing values determined be trial and error.
+  # Needed for LibreOffice.  Appear to be ingnored in Word.
   if (rs$font_size == 10)
-    hdr[length(hdr) + 1] <- "\\fs20"
+    hdr[length(hdr) + 1] <- "\\sl-225\\slmult0\\fs20"
   else if (rs$font_size == 12)
-    hdr[length(hdr) + 1] <- "\\fs24"
+    hdr[length(hdr) + 1] <- "\\sl-275\\slmult0\\fs24"
   else if (rs$font_size == 8)
-    hdr[length(hdr) + 1] <- "\\fs16"
+    hdr[length(hdr) + 1] <- "\\sl-180\\slmult0\\fs16"
   
   # Start with all lines
   body <- encodeRTF(ls)
@@ -141,17 +143,18 @@ write_rtf_output <- function(rs, ls, rtf_path, orig_path, tmp_dir) {
       # 3 = width
       # 4 = align
       
-      img <- get_image_rtf(spec[[1]], as.numeric(spec[[3]]), as.numeric(spec[[2]]), rs$units)
+      img <- get_image_rtf(spec[[1]], as.numeric(spec[[3]]), 
+                           as.numeric(spec[[2]]), rs$units, rs$font_size)
       ret[length(ret) + 1] <- spec[[1]]
       
-      # Create latex codes
+      # Create rtf codes
       if (spec[[4]] == "left") {
-        ltx <- paste0("\\par\\ql\n"  )
+        ltx <- paste0("\\par\\sl0\\ql\n"  )
 
       } else if (spec[[4]] == "right") {
-        ltx <- paste0("\\par\\qr\n"  )
+        ltx <- paste0("\\par\\sl0\\qr\n"  )
       } else  {
-        ltx <- paste0("\\par\\qc\n"  )
+        ltx <- paste0("\\par\\sl0\\qc\n"  )
       }
 
       # Replace original line with RTF codes
